@@ -2,9 +2,11 @@
 #from .driver_utils import Utilities
 #from .element_finder import Finder
 #from .scraping_utilities import Scraping_utilities
-from .profile import scrap_profile
 from .keyword import scrap_keyword
+from .profile import scrap_profile
+from .topic import scrap_topic
+
 #__all__ = ["Initializer",
 #           "Utilities", "Finder",
 #           "Scraping_utilities","scrap_profile","scrap_keyword"]
-__all__ = ["scrap_profile","scrap_keyword"]
+__all__ = ["scrap_profile", "scrap_keyword", "scrap_topic"]
